@@ -15,19 +15,17 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 
-import sys
-import os.path
 import os
-import unittest
+import os.path
 import time
+import unittest
 
-sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__), "..")))
-
-from variety.Util import Util, debounce, throttle, cache
+from variety.Util import Util, cache, debounce, throttle
 
 
 class TestUtil(unittest.TestCase):
-    def setUpClass():
+    @classmethod
+    def setUpClass(cls):
         # Chdir to the tests directory so that we can find our test images
         curdir = os.path.dirname(os.path.abspath(__file__))
         if curdir:
@@ -47,61 +45,61 @@ class TestUtil(unittest.TestCase):
         self.assertTrue(len(Util.get_local_name("a" * 1000 + ".jpg")) < 255)
 
     def test_split(self):
-        self.assertEqual(['a', 'b', 'c', 'd', 'e'], Util.split("a\nb,c ,,d\n   e"))
+        self.assertEqual(["a", "b", "c", "d", "e"], Util.split("a\nb,c ,,d\n   e"))
 
     def test_metadata(self):
-        self.assertTrue(os.path.exists('test.jpg'))
+        self.assertTrue(os.path.exists("test.jpg"))
         info = {
-            'sourceURL': 'b',
-            'imageURL': 'd',
-            'sourceName': 'a',
-            'sourceLocation': 'c',
-            'sourceType': 'flickr',
-            'author': 'автор',
-            'authorURL': 'url',
-            'keywords': ['дума1', 'дума2'],
-            'headline': 'проба1 проба1',
-            'description': 'проба2 проба2',
-            'sfwRating': 50,
-            'extraData': {'key1': 'val1', 'key2': 'val2'}
+            "sourceURL": "b",
+            "imageURL": "d",
+            "sourceName": "a",
+            "sourceLocation": "c",
+            "sourceType": "flickr",
+            "author": "автор",
+            "authorURL": "url",
+            "keywords": ["дума1", "дума2"],
+            "headline": "проба1 проба1",
+            "description": "проба2 проба2",
+            "sfwRating": 50,
+            "extraData": {"key1": "val1", "key2": "val2"},
         }
-        self.assertEqual(info, Util.read_metadata('test.jpg'))
-        self.assertTrue(Util.write_metadata('test.jpg', info))
-        self.assertEqual(info, Util.read_metadata('test.jpg'))
+        self.assertEqual(info, Util.read_metadata("test.jpg"))
+        self.assertTrue(Util.write_metadata("test.jpg", info))
+        self.assertEqual(info, Util.read_metadata("test.jpg"))
 
-        self.assertTrue(os.path.exists('test.svg'))
-        self.assertEqual(info, Util.read_metadata('test.svg'))
-        Util.write_metadata('test.svg', info)
-        self.assertEqual(info, Util.read_metadata('test.svg'))
+        self.assertTrue(os.path.exists("test.svg"))
+        self.assertEqual(info, Util.read_metadata("test.svg"))
+        Util.write_metadata("test.svg", info)
+        self.assertEqual(info, Util.read_metadata("test.svg"))
 
     def test_read_write_rating(self):
-        self.assertTrue(os.path.exists('test.jpg'))
-        self.assertEqual(None, Util.get_rating('test.jpg'))
+        self.assertTrue(os.path.exists("test.jpg"))
+        self.assertEqual(None, Util.get_rating("test.jpg"))
 
-        Util.set_rating('test.jpg', None)
-        self.assertEqual(None, Util.get_rating('test.jpg'))
+        Util.set_rating("test.jpg", None)
+        self.assertEqual(None, Util.get_rating("test.jpg"))
 
-        Util.set_rating('test.jpg', 4)
-        self.assertEqual(4, Util.get_rating('test.jpg'))
+        Util.set_rating("test.jpg", 4)
+        self.assertEqual(4, Util.get_rating("test.jpg"))
 
-        Util.set_rating('test.jpg', -1)
-        self.assertEqual(-1, Util.get_rating('test.jpg'))
+        Util.set_rating("test.jpg", -1)
+        self.assertEqual(-1, Util.get_rating("test.jpg"))
 
-        Util.set_rating('test.jpg', 0)
-        self.assertEqual(0, Util.get_rating('test.jpg'))
+        Util.set_rating("test.jpg", 0)
+        self.assertEqual(0, Util.get_rating("test.jpg"))
 
-        Util.set_rating('test.jpg', None)
-        self.assertEqual(None, Util.get_rating('test.jpg'))
+        Util.set_rating("test.jpg", None)
+        self.assertEqual(None, Util.get_rating("test.jpg"))
 
         try:
-            Util.set_rating('test.jpg', -10)
+            Util.set_rating("test.jpg", -10)
             self.assertTrue(False, "Exception expected")
         except ValueError:
-            pass #OK
+            pass  # OK
 
     def test_find_unique_name(self):
-        self.assertEqual('/etc/fstab_1', Util.find_unique_name('/etc/fstab'))
-        self.assertEqual('/etc/bash_1.bashrc', Util.find_unique_name('/etc/bash.bashrc'))
+        self.assertEqual("/etc/fstab_1", Util.find_unique_name("/etc/fstab"))
+        self.assertEqual("/etc/bash_1.bashrc", Util.find_unique_name("/etc/bash.bashrc"))
 
     def test_folderpath(self):
         self.assertEqual("/", Util.folderpath("/"))
@@ -109,7 +107,9 @@ class TestUtil(unittest.TestCase):
 
     def test_gtk_to_fcmatch_font(self):
         self.assertEqual(
-            ("Bitstream Charter:Bold:Italic:10", '10'), Util.gtk_to_fcmatch_font("Bitstream Charter Bold Italic 10"))
+            ("Bitstream Charter:Bold:Italic:10", "10"),
+            Util.gtk_to_fcmatch_font("Bitstream Charter Bold Italic 10"),
+        )
 
     def test_file_in(self):
         self.assertTrue(Util.file_in("/a/b/a.txt", "/a/"))
@@ -141,8 +141,12 @@ class TestUtil(unittest.TestCase):
         self.assertEqual("6af710446c1554d7bc79d7939d6900e4", Util.md5file("test.jpg"))
 
     def test_collapseuser(self):
-        self.assertEqual("~/.config/variety", Util.collapseuser("%s/.config/variety" % os.path.expanduser('~')))
-        self.assertEqual("/home/peteraaa/.config/variety", Util.collapseuser("/home/peteraaa/.config/variety"))
+        self.assertEqual(
+            "~/.config/variety", Util.collapseuser("%s/.config/variety" % os.path.expanduser("~"))
+        )
+        self.assertEqual(
+            "/home/peteraaa/.config/variety", Util.collapseuser("/home/peteraaa/.config/variety")
+        )
         self.assertEqual("/media/.config/variety", Util.collapseuser("/media/.config/variety"))
 
     def test_random_hash(self):
@@ -152,64 +156,73 @@ class TestUtil(unittest.TestCase):
             self.assertEqual(32, len(x))
 
     def test_get_file_icon_name(self):
-        self.assertEqual("folder", Util.get_file_icon_name("/xxx/yyy/zzz")) # nonexistent
+        self.assertEqual("folder", Util.get_file_icon_name("/xxx/yyy/zzz"))  # nonexistent
         self.assertEqual("user-home", Util.get_file_icon_name("~"))
         self.assertEqual("folder-pictures", Util.get_file_icon_name("~/Pictures"))
 
     def test_get_xdg_pictures_folder(self):
-        self.assertEqual(os.path.expanduser('~/Pictures'), Util.get_xdg_pictures_folder())
+        self.assertEqual(os.path.expanduser("~/Pictures"), Util.get_xdg_pictures_folder())
 
     def test_safe_map(self):
         def f(i):
-            if i <= 10: raise Exception
+            if i <= 10:
+                raise Exception
             return i
-        self.assertEqual([20,30], list(Util.safe_map(f, [1,5,20,10,30,4])))
+
+        self.assertEqual([20, 30], list(Util.safe_map(f, [1, 5, 20, 10, 30, 4])))
 
     def test_fetch(self):
         resp = Util.fetch("//google.com")
         self.assertTrue(len(resp) > 0)
 
+    def test_convert_url(self):
+        self.assertEqual(
+            "wallpapers_net_some_category_html",
+            Util.convert_to_filename("http://wallpapers.net/some-category.html"),
+        )
+
     def test_get_size(self):
-        self.assertEqual((32, 32), Util.get_size('test.jpg'))
-        self.assertRaises(Exception, lambda: Util.get_size('fake_image.jpg'))
+        self.assertEqual((32, 32), Util.get_size("test.jpg"))
+        self.assertRaises(Exception, lambda: Util.get_size("fake_image.jpg"))
 
     def test_is_image(self):
-        self.assertTrue(Util.is_image('test.jpg'))
-        self.assertTrue(Util.is_image('test.jpg', check_contents=True))
-        self.assertTrue(Util.is_image('fake_image.jpg'))
-        self.assertFalse(Util.is_image('fake_image.jpg', check_contents=True))
+        self.assertTrue(Util.is_image("test.jpg"))
+        self.assertTrue(Util.is_image("test.jpg", check_contents=True))
+        self.assertTrue(Util.is_image("fake_image.jpg"))
+        self.assertFalse(Util.is_image("fake_image.jpg", check_contents=True))
 
     def test_is_animated_gif(self):
-        self.assertFalse(Util.is_animated_gif('test.jpg'))
-        self.assertTrue(Util.is_animated_gif('animated.gif'))
-        self.assertFalse(Util.is_animated_gif('not-animated.gif'))
+        self.assertFalse(Util.is_animated_gif("test.jpg"))
+        self.assertTrue(Util.is_animated_gif("animated.gif"))
+        self.assertFalse(Util.is_animated_gif("not-animated.gif"))
 
     def test_is_dead_or_not_image(self):
         self.assertTrue(Util.is_dead_or_not_image(None))
-        self.assertTrue(Util.is_dead_or_not_image('not a URL'))
-        self.assertTrue(Util.is_dead_or_not_image('http://www.google.com/'))
-        self.assertTrue(Util.is_dead_or_not_image('http://vrty.org/'))
-        self.assertTrue(Util.is_dead_or_not_image('http://www.google.com/dejkjdrelkjflkrejfjre'))
-        self.assertFalse(Util.is_dead_or_not_image('http://upload.wikimedia.org/wikipedia/commons/5/53/Wikipedia-logo-en-big.png'))
-        self.assertFalse(Util.is_dead_or_not_image('https://farm8.staticflickr.com/7133/7527967878_85fea93129_o.jpg'))
-        self.assertFalse(Util.is_dead_or_not_image('http://interfacelift.com/wallpaper/D98ef829/00899_rustedbolt_2560x1600.jpg'))
-        self.assertTrue(Util.is_dead_or_not_image('http://wallpapers.wallbase.cc/rozne/wallpaper-1227671.jpg'))
-        self.assertTrue(Util.is_dead_or_not_image('http://ns223506.ovh.net/rozne/a1b2/wallpaper-1996019.png'))
-
-    def test_guess_image_url(self):
-        self.assertEqual('https://farm5.staticflickr.com/4032/4558166441_4e34855b39_o.jpg',
-                          Util.guess_image_url({'sourceURL': 'https://www.flickr.com/photos/83646108@N00/4558166441'}))
-
-        self.assertEqual('https://farm5.staticflickr.com/4077/4768189432_24275ea76b_b.jpg',
-                          Util.guess_image_url({'sourceURL': 'http://www.flickr.com/photos/52821721@N00/4768189432'}))
-
-        self.assertEqual('http://fc04.deviantart.net/fs71/i/2011/319/4/f/scarlet_leaf_wallpaper_by_venomxbaby-d4gc238.jpg',
-                          Util.guess_image_url({'sourceURL': 'http://fc04.deviantart.net/fs71/i/2011/319/4/f/scarlet_leaf_wallpaper_by_venomxbaby-d4gc238.jpg'}))
-
-    def test_guess_source_type(self):
-        self.assertEqual(None, Util.guess_source_type({}))
-        self.assertEqual('mediarss', Util.guess_source_type({'sourceName': 'host.com', 'sourceLocation': 'http://host.com/rss'}))
-        self.assertEqual('mediarss', Util.guess_source_type({'sourceName': 'camelid.deviantart.com', 'sourceLocation': 'http://backend.deviantart.com/rss.xml?type=deviation&q=by%3ACamelid+sort%3Atime+meta%3Aall'}))
+        self.assertTrue(Util.is_dead_or_not_image("not a URL"))
+        self.assertTrue(Util.is_dead_or_not_image("http://www.google.com/"))
+        self.assertTrue(Util.is_dead_or_not_image("http://vrty.org/"))
+        self.assertTrue(Util.is_dead_or_not_image("http://www.google.com/dejkjdrelkjflkrejfjre"))
+        self.assertFalse(
+            Util.is_dead_or_not_image(
+                "http://upload.wikimedia.org/wikipedia/commons/5/53/Wikipedia-logo-en-big.png"
+            )
+        )
+        self.assertFalse(
+            Util.is_dead_or_not_image(
+                "https://farm8.staticflickr.com/7133/7527967878_85fea93129_o.jpg"
+            )
+        )
+        self.assertFalse(
+            Util.is_dead_or_not_image(
+                "http://interfacelift.com/wallpaper/D98ef829/00899_rustedbolt_2560x1600.jpg"
+            )
+        )
+        self.assertTrue(
+            Util.is_dead_or_not_image("http://wallpapers.wallbase.cc/rozne/wallpaper-1227671.jpg")
+        )
+        self.assertTrue(
+            Util.is_dead_or_not_image("http://ns223506.ovh.net/rozne/a1b2/wallpaper-1996019.png")
+        )
 
     def test_debounce(self):
         """ Test that the increment function is being debounced.
@@ -224,7 +237,7 @@ class TestUtil(unittest.TestCase):
         increment()
         increment()
         time.sleep(0.4)
-        self.assertTrue(count[0]== 0)
+        self.assertTrue(count[0] == 0)
         increment()
         increment()
         increment()
@@ -233,7 +246,6 @@ class TestUtil(unittest.TestCase):
         time.sleep(0.6)
         self.assertTrue(count[0] == 1)
 
-
     def test_throttle_no_trailing(self):
         count = [0]
 
@@ -287,5 +299,6 @@ class TestUtil(unittest.TestCase):
 
         self.assertEqual(573147844013817084101, fib(100))
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
